import * as session from 'express-session';
import { Collection, CommonOptions, MongoClientOptions } from 'mongodb';
export declare type ConnectMongoOptions = {
    mongoUrl: string;
    collectionName?: string;
    mongoOptions?: MongoClientOptions;
    dbName?: string;
    ttl?: number;
    createAutoRemoveIdx?: boolean;
    touchAfter?: number;
    stringify?: boolean;
    serialize?: (a: any) => any;
    unserialize?: (a: any) => any;
    writeOperationOptions?: CommonOptions;
    transformId?: (a: any) => any;
};
declare type ErrorOrNull = Error | null;
export default class MongoStoreV2 extends session.Store {
    private clientP;
    collectionP: Promise<Collection>;
    private options;
    private transformFunctions;
    constructor({ collectionName, ttl, mongoOptions, createAutoRemoveIdx, touchAfter, stringify, ...required }: ConnectMongoOptions);
    static create(options: ConnectMongoOptions): MongoStoreV2;
    private computeStorageId;
    /**
     * Get a session from the store given a session ID (sid)
     * @param sid session ID
     */
    get(sid: string, callback: (err: ErrorOrNull, session?: session.SessionData | null) => void): void;
    /**
     * Upsert a session into the store given a session ID (sid) and session (session) object.
     * @param sid session ID
     * @param session session object
     */
    set(sid: string, session: session.SessionData, callback?: (err: ErrorOrNull) => void): void;
    touch(sid: string, session: session.SessionData & {
        lastModified?: Date;
    }, callback?: (err: ErrorOrNull) => void): void;
    /**
     * Get all sessions in the store as an array
     */
    all(callback: (err: ErrorOrNull, obj?: session.SessionData[] | {
        [sid: string]: session.SessionData;
    } | null) => void): void;
    /**
     * Destroy/delete a session from the store given a session ID (sid)
     * @param sid session ID
     */
    destroy(sid: string, callback?: (err: ErrorOrNull) => void): void;
    /**
     * Get the count of all sessions in the store
     */
    length(callback: (err: ErrorOrNull, length: number) => void): void;
    /**
     * Delete all sessions from the store.
     */
    clear(callback?: (err: ErrorOrNull) => void): void;
    /**
     * Close database connection
     */
    close(): Promise<void>;
}
export {};
